@@ -341,7 +341,7 @@ soup_session_class_init (SoupSessionClass *session_class)
 			      G_SIGNAL_RUN_FIRST,
 			      0, /* FIXME? */
 			      NULL, NULL,
-			      soup_marshal_NONE__OBJECT,
+			      _soup_marshal_NONE__OBJECT,
 			      G_TYPE_NONE, 1,
 			      SOUP_TYPE_MESSAGE);
 
@@ -361,7 +361,7 @@ soup_session_class_init (SoupSessionClass *session_class)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (SoupSessionClass, request_started),
 			      NULL, NULL,
-			      soup_marshal_NONE__OBJECT_OBJECT,
+			      _soup_marshal_NONE__OBJECT_OBJECT,
 			      G_TYPE_NONE, 2,
 			      SOUP_TYPE_MESSAGE,
 			      SOUP_TYPE_SOCKET);
@@ -384,7 +384,7 @@ soup_session_class_init (SoupSessionClass *session_class)
 			      G_SIGNAL_RUN_FIRST,
 			      0, /* FIXME? */
 			      NULL, NULL,
-			      soup_marshal_NONE__OBJECT,
+			      _soup_marshal_NONE__OBJECT,
 			      G_TYPE_NONE, 1,
 			      SOUP_TYPE_MESSAGE);
 
@@ -417,7 +417,7 @@ soup_session_class_init (SoupSessionClass *session_class)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (SoupSessionClass, authenticate),
 			      NULL, NULL,
-			      soup_marshal_NONE__OBJECT_OBJECT_BOOLEAN,
+			      _soup_marshal_NONE__OBJECT_OBJECT_BOOLEAN,
 			      G_TYPE_NONE, 3,
 			      SOUP_TYPE_MESSAGE,
 			      SOUP_TYPE_AUTH,
@@ -440,7 +440,7 @@ soup_session_class_init (SoupSessionClass *session_class)
 			      G_SIGNAL_RUN_FIRST,
 			      0,
 			      NULL, NULL,
-			      soup_marshal_NONE__OBJECT,
+			      _soup_marshal_NONE__OBJECT,
 			      G_TYPE_NONE, 1,
 			      /* SoupConnection is private, so we can't use
 			       * SOUP_TYPE_CONNECTION here.
@@ -464,7 +464,7 @@ soup_session_class_init (SoupSessionClass *session_class)
 			      G_SIGNAL_RUN_FIRST,
 			      0,
 			      NULL, NULL,
-			      soup_marshal_NONE__OBJECT,
+			      _soup_marshal_NONE__OBJECT,
 			      G_TYPE_NONE, 1,
 			      /* SoupConnection is private, so we can't use
 			       * SOUP_TYPE_CONNECTION here.
@@ -1633,9 +1633,12 @@ soup_session_redirect_message (SoupSession *session, SoupMessage *msg)
 		return FALSE;
 
 	item = soup_message_queue_lookup (soup_session_get_queue (session), msg);
-	if (!item)
+	if (!item) {
+		soup_uri_free (new_uri);
 		return FALSE;
+	}
 	if (item->redirection_count >= SOUP_SESSION_MAX_REDIRECTION_COUNT) {
+		soup_uri_free (new_uri);
 		soup_session_cancel_message (session, msg, SOUP_STATUS_TOO_MANY_REDIRECTS);
 		soup_message_queue_item_unref (item);
 		return FALSE;
@@ -1973,7 +1976,8 @@ soup_session_unqueue_item (SoupSession          *session,
 	SoupSessionHost *host;
 
 	if (item->conn) {
-		soup_connection_set_state (item->conn, SOUP_CONNECTION_IDLE);
+		if (soup_connection_get_state (item->conn) == SOUP_CONNECTION_IN_USE)
+			soup_connection_set_state (item->conn, SOUP_CONNECTION_IDLE);
 		soup_message_queue_item_set_connection (item, NULL);
 	}
 
